@@ -71,10 +71,12 @@ class Pg:
     async def sort_fetchs(self, target, **opt):
         "データをソートして取得"
 
-        column = f"{list(opt.keys())[0]} = $1"
-        limit = f"{list(opt.keys())[1]} $2"
+        keys = list(opt.keys())
 
-        contents = await self.pool.fetch(f'SELECT * FROM {self.table} WHERE {column} ODER BY {target} DESC {limit}', *opt.values())
+        column = f"{keys[0]} = $1"
+        limit = f"{keys[1]} $2"
+
+        contents = await self.pool.fetch(f'SELECT * FROM {self.table} WHERE {column} ORDER BY {target} DESC {limit}', *opt.values())
         return contents
         
 
